@@ -5,43 +5,43 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="54"/>
-        <location filename="../mainwindow.cpp" line="258"/>
-        <location filename="../mainwindow.cpp" line="305"/>
+        <location filename="../mainwindow.cpp" line="53"/>
+        <location filename="../mainwindow.cpp" line="244"/>
+        <location filename="../mainwindow.cpp" line="289"/>
         <source>MX Cleanup</source>
-        <translation type="unfinished"></translation>
+        <translation>MX Čiščenje</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="26"/>
         <source>Clean Folders</source>
-        <translation type="unfinished"></translation>
+        <translation>Očisti imenike</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="86"/>
         <source>Delete Logs</source>
-        <translation type="unfinished"></translation>
+        <translation>Izbriši dnevnike</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="98"/>
         <source>Old logs</source>
-        <translation type="unfinished"></translation>
+        <translation>Stari dnevniki</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="117"/>
         <source>All logs</source>
-        <translation type="unfinished"></translation>
+        <translation>Vsi dnevniki</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="130"/>
         <location filename="../mainwindow.ui" line="387"/>
         <location filename="../mainwindow.ui" line="451"/>
         <source>Don&apos;t empty</source>
-        <translation type="unfinished"></translation>
+        <translation>Ne briši</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="192"/>
         <source>Display help </source>
-        <translation type="unfinished"></translation>
+        <translation>Prikaži pomoč</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="195"/>
@@ -51,27 +51,27 @@
     <message>
         <location filename="../mainwindow.ui" line="202"/>
         <source>Alt+H</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+H</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="231"/>
         <source>About this application</source>
-        <translation type="unfinished"></translation>
+        <translation>O tem programu</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="234"/>
         <source>About...</source>
-        <translation type="unfinished"></translation>
+        <translation>O programu...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="241"/>
         <source>Alt+B</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="273"/>
         <source>Quit application</source>
-        <translation type="unfinished"></translation>
+        <translation>Zapri aplikacijo</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="276"/>
@@ -81,149 +81,149 @@
     <message>
         <location filename="../mainwindow.ui" line="283"/>
         <source>Alt+N</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="321"/>
         <source>Apply</source>
-        <translation type="unfinished"></translation>
+        <translation>Potrdi</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="349"/>
         <source>Empty Trash</source>
-        <translation type="unfinished"></translation>
+        <translation>Izprazni smeti</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="364"/>
         <source>Selected user</source>
-        <translation type="unfinished"></translation>
+        <translation>Izbrani uporabnik</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="380"/>
         <source>All users</source>
-        <translation type="unfinished"></translation>
+        <translation>Vsi uporabniki</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="416"/>
         <source>Clear APT Cache</source>
-        <translation type="unfinished"></translation>
+        <translation>Očisti medpomnilnik APT</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="428"/>
         <source>Old files</source>
-        <translation type="unfinished"></translation>
+        <translation>Stare datoteke</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="444"/>
         <source>All files</source>
-        <translation type="unfinished"></translation>
+        <translation>Vse datoteke</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="480"/>
         <source>Free Disk Space for User</source>
-        <translation type="unfinished"></translation>
+        <translation>Sprosti prostor na disku za uporabnika</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="492"/>
         <location filename="../mainwindow.ui" line="505"/>
         <source>Select user to repair</source>
-        <translation type="unfinished"></translation>
+        <translation>Izberi uporabnika za popravilo</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="508"/>
         <source>Select user:</source>
-        <translation type="unfinished"></translation>
+        <translation>Izberi uporabnika:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="524"/>
         <source>Graphical Tool for Analyzing Disk Usage</source>
-        <translation type="unfinished"></translation>
+        <translation>Grafično orodje za analiziranje rabe diska</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="530"/>
         <source>Run Disk Usage Analyzer</source>
-        <translation type="unfinished"></translation>
+        <translation>Zaženi analizo rabe diska</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="544"/>
         <source>Schedule</source>
-        <translation type="unfinished"></translation>
+        <translation>Termin</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="556"/>
         <source>No automatic clean</source>
-        <translation type="unfinished"></translation>
+        <translation>Brez samodejnega čiščenja</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="563"/>
         <source>Daily</source>
-        <translation type="unfinished"></translation>
+        <translation>Dnevno</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="570"/>
         <source>Weekly</source>
-        <translation type="unfinished"></translation>
+        <translation>Tedensko</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="577"/>
         <source>Monthly</source>
-        <translation type="unfinished"></translation>
+        <translation>Mesečno</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="249"/>
+        <location filename="../mainwindow.cpp" line="235"/>
         <source>Done</source>
-        <translation type="unfinished"></translation>
+        <translation>Zaključeno</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="250"/>
+        <location filename="../mainwindow.cpp" line="236"/>
         <source>Cleanup command done</source>
-        <translation type="unfinished"></translation>
+        <translation>Čiščenje je končano</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="251"/>
+        <location filename="../mainwindow.cpp" line="237"/>
         <source>%1 MiB were freed</source>
-        <translation type="unfinished"></translation>
+        <translation>%1 MiB je bilo sproščeno</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="258"/>
+        <location filename="../mainwindow.cpp" line="244"/>
         <source>About</source>
         <translation>O programu</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="259"/>
+        <location filename="../mainwindow.cpp" line="245"/>
         <source>Version: </source>
-        <translation type="unfinished"></translation>
+        <translation>Različica:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="260"/>
+        <location filename="../mainwindow.cpp" line="246"/>
         <source>Quick and safe removal of old files</source>
-        <translation type="unfinished"></translation>
+        <translation>Hitro in varno odstranjevanje starih datotek</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="262"/>
+        <location filename="../mainwindow.cpp" line="248"/>
         <source>Copyright (c) MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="263"/>
-        <location filename="../mainwindow.cpp" line="273"/>
+        <location filename="../mainwindow.cpp" line="249"/>
+        <location filename="../mainwindow.cpp" line="259"/>
         <source>License</source>
         <translation>Licenca</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="264"/>
+        <location filename="../mainwindow.cpp" line="250"/>
         <source>Changelog</source>
-        <translation type="unfinished"></translation>
+        <translation>Dnevnik sprememb</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="265"/>
+        <location filename="../mainwindow.cpp" line="251"/>
         <source>Cancel</source>
         <translation>Prekliči</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="286"/>
+        <location filename="../mainwindow.cpp" line="271"/>
         <source>&amp;Close</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Zapri</translation>
     </message>
 </context>
 <context>
@@ -231,7 +231,7 @@
     <message>
         <location filename="../main.cpp" line="52"/>
         <source>You must run this program as root.</source>
-        <translation type="unfinished"></translation>
+        <translation>Ta program morate zagnati kot root</translation>
     </message>
 </context>
 </TS>
